=======
Credits
=======

Development Lead
----------------

* `Moritz E. Beber <https://github.com/Midnighter>`_

Contributors
------------

* `Nikolaus Sonnenschein <https://github.com/phantomas1234>`_
* `Pankaj Kumar Singh <https://github.com/pankaj28843>`_
* `Ida Bonde <https://github.com/IdaBonde>`_
